<?php // casino-slots777.com
/**
 * Plugin Name: Мой SEO Плагин
 * Description: Плагин для управления SEO настройками различных типов записей и таксономий.
 * Version: 1.0
 * Author: alpaka
 * Text Domain: my-seo-plugin
 */


// 1. Добавляем страницу настроек
add_action('admin_menu', 'my_seo_plugin_settings_menu');
function my_seo_plugin_settings_menu() {
    add_menu_page(
        'SEO Настройки',
        'Мой SEO Плагин',
        'manage_options',
        'my-seo-plugin-settings',
        'my_seo_plugin_main_settings_page'
    );
}

// 2. Регистрируем поля для гугл вебмастер
add_action('admin_init', 'my_seo_plugin_settings_init');
function my_seo_plugin_settings_init() {
    register_setting('my_seo_plugin_options_group', 'my_seo_plugin_google_webmaster_code');
}

// 3. Подключаем теймплейт страницы настроек
function my_seo_plugin_main_settings_page() {
    $post_types = get_post_types(['public' => true], 'objects');
    $taxonomies = get_taxonomies(['public' => true], 'objects');
    $google_webmaster_code = get_option('my_seo_plugin_google_webmaster_code');
	include plugin_dir_path(__FILE__) . 'templates/main-settings-page.php';
}

// 4. Рендерим страницу настроек
function my_seo_plugin_render_settings_page($type, $name) {
    $saved = false;
    $supports_archive = false;

    // Проверяем, поддерживает ли тип записи архив
    if ($type === 'post_type') {
        // Получаем объект типа записи
        $post_type_object = get_post_type_object($name);

        // Для стандартной записи всегда поддерживается архив
        if ($name === 'post' || ($post_type_object && $post_type_object->has_archive)) {
            $supports_archive = true;
        }
    }
	
    if ($_SERVER['REQUEST_METHOD'] == 'POST' && check_admin_referer('my_seo_plugin_save_settings', 'my_seo_plugin_nonce')) {
        update_option("seo_title_{$type}_{$name}", sanitize_text_field($_POST['seo_title']));
        update_option("meta_description_{$type}_{$name}", sanitize_textarea_field($_POST['meta_description']));
        update_option("show_in_search_{$type}_{$name}", sanitize_text_field($_POST['show_in_search']));
		update_option("add_meta_boxes_{$type}_{$name}", sanitize_text_field($_POST['add_meta_boxes']));
		
		if ($supports_archive) {
			update_option("archive_seo_title_{$type}_{$name}", sanitize_text_field($_POST['archive_seo_title']));
			update_option("archive_meta_description_{$type}_{$name}", sanitize_textarea_field($_POST['archive_meta_description']));
			update_option("archive_indexing_{$type}_{$name}", sanitize_text_field($_POST['archive_indexing']));
		}
		
		$saved = true;
    }

	// Определение, является ли тип таксономией или типом записи
	$isTaxonomy = $type === 'taxonomy';
	$isPostType = $type === 'post_type';

	// Определение значений по умолчанию
	$defaultSeoTitle = $isPostType ? '{post_title} - {site_title}' : ($isTaxonomy ? '{term_title} - {site_title}' : '');

	// Получение сохраненных значений или использование значений по умолчанию
	$seo_title = get_option("seo_title_{$type}_{$name}", $defaultSeoTitle);
	$meta_description = get_option("meta_description_{$type}_{$name}", '');
	$show_in_search = get_option("show_in_search_{$type}_{$name}", 'yes');

    // Определяем, какой тип плейсхолдера использовать и текст кнопки
    $isPostType = $type === 'post_type';
    $titlePlaceholder = $isPostType ? '{post_title}' : '{term_title}';
    $buttonText = $isPostType ? 'Вставити назву запису' : 'Вставити назву терміну';

	// Для архива типов постов
	$archive_seo_title = get_option("archive_seo_title_{$type}_{$name}", '{post_type} - {site_title}');
	$archive_meta_description = get_option("archive_meta_description_{$type}_{$name}", '');
	$archive_indexing = get_option("archive_indexing_{$type}_{$name}", 'yes');
	
	include 'templates/settings-form.php';

}

// 5. Шорткоды для плейсхолдеров
function replace_seo_placeholders($string) {
    global $post;
    $queried_object = get_queried_object();

    // Массив замен для плейсхолдеров
    $replacements = [
        '{post_title}' => is_singular() ? $post->post_title : '',
        '{site_title}' => get_bloginfo('name'),
        '{current_year}' => date('Y'),
        '{term_title}' => ''
    ];

    // Если это таксономия, заменяем {term_title} на название термина
    if (!empty($queried_object) && isset($queried_object->taxonomy)) {
        $replacements['{term_title}'] = $queried_object->name;
    }

    // Если это архив типа записи, добавляем {post_type}
    if (is_post_type_archive() ) {
        $post_type = get_query_var('post_type');
        $post_type_object = get_post_type_object($post_type);
        $replacements['{post_type}'] = $post_type_object ? $post_type_object->labels->name : $post_type;
    }
    if (is_home() ) {
        $post_type = 'post';
        $post_type_object = get_post_type_object($post_type);
        $replacements['{post_type}'] = $post_type_object ? $post_type_object->labels->name : $post_type;
    }	
    // Проходим по всем заменам и подставляем значения в строку
    foreach ($replacements as $placeholder => $replacement) {
        $string = str_replace($placeholder, $replacement, $string);
    }

    return $string;
}


// 6. Хук для добавления метабоксов к записям
add_action('add_meta_boxes', 'my_seo_plugin_add_meta_boxes');
function my_seo_plugin_add_meta_boxes() {
    $post_types = get_post_types(['public' => true], 'names');
    foreach ($post_types as $post_type) {
        if ('yes' === get_option("add_meta_boxes_post_type_{$post_type}", 'no')) {
            add_meta_box('my_seo_plugin_meta_box', 'SEO Настройки записи', 'my_seo_plugin_meta_box_callback', $post_type, 'normal', 'high');
        }
    }
}

// 7. Хук для добавления метабоксов к терминам таксономий
add_action('admin_init', 'my_seo_plugin_add_taxonomy_meta_boxes');
function my_seo_plugin_add_taxonomy_meta_boxes() {
    $taxonomies = get_taxonomies(['public' => true], 'names');
    foreach ($taxonomies as $taxonomy) {
        if ('yes' === get_option("add_meta_boxes_taxonomy_{$taxonomy}", 'no')) {
            add_action("{$taxonomy}_edit_form_fields", 'my_seo_plugin_taxonomy_meta_box_callback', 10, 2);
            add_action("edited_{$taxonomy}", 'my_seo_plugin_save_taxonomy_meta_data', 10, 2);
        }
    }
}

// 8. Вывод полей на странице редактиварония термина
function my_seo_plugin_taxonomy_meta_box_callback($term, $taxonomy) {
    // Получение сохранённых данных или значений по умолчанию
    $default_seo_title = get_option("seo_title_taxonomy_{$taxonomy}", '{term_title} - {site_title}');
    $default_meta_description = get_option("meta_description_taxonomy_{$taxonomy}", '');
    $default_show_in_search = get_option("show_in_search_taxonomy_{$taxonomy}", 'yes');
    // Получение значений из метаполей или установка умолчаний    
    $seo_title = get_term_meta($term->term_id, '_my_seo_plugin_seo_title', true) ?: $default_seo_title;
    $meta_description = get_term_meta($term->term_id, '_my_seo_plugin_meta_description', true) ?: $default_meta_description;
    $show_in_search = get_term_meta($term->term_id, '_my_seo_plugin_show_in_search', true) ?: $default_show_in_search;
    wp_nonce_field('my_seo_plugin_taxonomy_meta_box_nonce', 'my_seo_plugin_taxonomy_meta_box_nonce_field');
    // Подключение инклюд-файла из папки templates
    include plugin_dir_path(__FILE__) . 'templates/meta-box-fields.php'; 
}

// 9. Вывод полей на странице редактиварония записи
function my_seo_plugin_meta_box_callback($post) {
    // Получение умолчаний из настроек плагина
    $post_type = get_post_type($post);
    $default_seo_title = get_option("seo_title_post_type_{$post_type}", '{post_title} - {site_title}');
    $default_meta_description = get_option("meta_description_post_type_{$post_type}", '');
    $default_show_in_search = get_option("show_in_search_post_type_{$post_type}", 'yes');
    // Получение значений из метаполей или установка умолчаний
    $seo_title = get_post_meta($post->ID, '_my_seo_plugin_seo_title', true) ?: $default_seo_title;
    $meta_description = get_post_meta($post->ID, '_my_seo_plugin_meta_description', true) ?: $default_meta_description;
    $show_in_search = get_post_meta($post->ID, '_my_seo_plugin_show_in_search', true) ?: $default_show_in_search;
	wp_nonce_field('my_seo_plugin_meta_box_nonce', 'my_seo_plugin_meta_box_nonce_field');	
    // Подключение шаблона
    include plugin_dir_path(__FILE__) . 'templates/post-meta-box.php';
}

// 10. Сохранение данных из метабокса для таксономий
function my_seo_plugin_save_taxonomy_meta_data($term_id) {
    // Проверяем nonce
    if (!isset($_POST['my_seo_plugin_taxonomy_meta_box_nonce_field']) ||
        !wp_verify_nonce($_POST['my_seo_plugin_taxonomy_meta_box_nonce_field'], 'my_seo_plugin_taxonomy_meta_box_nonce')) {
        return;
    }
    // Сохраняем данные с очисткой
    if (isset($_POST['my_seo_plugin_seo_title'])) {
        update_term_meta($term_id, '_my_seo_plugin_seo_title', sanitize_text_field($_POST['my_seo_plugin_seo_title']) );
    }
    if (isset($_POST['my_seo_plugin_meta_description'])) {
        update_term_meta($term_id, '_my_seo_plugin_meta_description', sanitize_textarea_field($_POST['my_seo_plugin_meta_description']) );
    }
    if (isset($_POST['my_seo_plugin_show_in_search'])) {
        update_term_meta($term_id, '_my_seo_plugin_show_in_search', $_POST['my_seo_plugin_show_in_search'] );
    }
}

// 11. Сохранение данных из метабокса для постов
add_action('save_post', 'my_seo_plugin_save_post_data');
function my_seo_plugin_save_post_data($post_id) {
    if (!isset($_POST['my_seo_plugin_meta_box_nonce_field']) ||
        !wp_verify_nonce($_POST['my_seo_plugin_meta_box_nonce_field'], 'my_seo_plugin_meta_box_nonce')) {
        return;
    }
    if (array_key_exists('my_seo_plugin_seo_title', $_POST)) {
        update_post_meta($post_id, '_my_seo_plugin_seo_title', sanitize_text_field($_POST['my_seo_plugin_seo_title']) );
    }
    if (array_key_exists('my_seo_plugin_meta_description', $_POST)) {
        update_post_meta($post_id, '_my_seo_plugin_meta_description', sanitize_textarea_field($_POST['my_seo_plugin_meta_description']) );
    }
    if (array_key_exists('my_seo_plugin_show_in_search', $_POST)) {
        update_post_meta($post_id, '_my_seo_plugin_show_in_search', $_POST['my_seo_plugin_show_in_search'] );
    }
}

// 12. Выводим гугл вебмастер тег в хедере на главной странице
function add_custom_meta_tag() {
    if (is_front_page()) {
        // Получаем значение из опции плагина
        $google_webmaster_code = get_option('my_seo_plugin_google_webmaster_code');

        // Проверяем, что значение существует и не пустое
        if (!empty($google_webmaster_code)) {
            echo $google_webmaster_code; // Выводим метатег напрямую
        }
    }
}
add_action('wp_head', 'add_custom_meta_tag');

// 13. Выводим в head meta name="robots" content="index, follow"
function my_seo_plugin_filter_robots($robots) {
    $show_in_search = null;

    // Проверяем для конкретной записи
    if (is_singular()) { // Для отдельных записей
        $post_id = get_the_ID();
        $post_type = get_post_type($post_id);

        // Сначала проверяем метаданные записи
        $show_in_search = get_post_meta($post_id, '_my_seo_plugin_show_in_search', true);

        // Если метаданных нет, используем значение из общих настроек для типа записи
        if (empty($show_in_search)) {
            $show_in_search = get_option("show_in_search_post_type_{$post_type}", 'yes');
        }

    } elseif (is_category() || is_tag() || is_tax()) { // Для категорий, тегов и таксономий
        $term = get_queried_object();
        if ($term && isset($term->term_id)) {
            $taxonomy = $term->taxonomy;

            // Сначала проверяем метаданные термина
            $show_in_search = get_term_meta($term->term_id, '_my_seo_plugin_show_in_search', true);

            // Если метаданных нет, используем значение из общих настроек для таксономии
            if (empty($show_in_search)) {
                $show_in_search = get_option("show_in_search_taxonomy_{$taxonomy}", 'yes');
            }
        }

    } elseif (is_post_type_archive()) { // Для архивов пользовательских типов записей
        $post_type = get_query_var('post_type');

        // Используем значение из настроек для архива типа записи
        $show_in_search = get_option("archive_indexing_post_type_{$post_type}", 'yes');
    }

    // Настраиваем мета-теги robots
    if ($show_in_search === 'no') {
        $robots['noindex'] = true;
        $robots['nofollow'] = true;
        unset($robots['max-image-preview']); // Отключаем max-image-preview
    } else {
        unset($robots['noindex'], $robots['nofollow']); // Убираем ограничения, если индексирование разрешено
    }

    return $robots;
}
add_filter('wp_robots', 'my_seo_plugin_filter_robots');

/* Выводим в head сео-теги тайтл и дескрипшн */
function my_seo_plugin_output_seo_tags() {
    global $post;

    // Инициализация значений
    $seo_title = '';
    $meta_description = '';

    // Проверяем тип страницы
    if (is_singular() && isset($post)) {
        $post_type = get_post_type($post);
        $seo_title = get_post_meta($post->ID, '_my_seo_plugin_seo_title', true) ?: get_option("seo_title_post_type_{$post_type}", '{post_title} - {site_title}');
        $meta_description = get_post_meta($post->ID, '_my_seo_plugin_meta_description', true) ?: get_option("meta_description_post_type_{$post_type}", '');
    } elseif (is_category() || is_tag() || is_tax()) {
        $term = get_queried_object();
        if ($term && isset($term->term_id)) {
            $seo_title = get_term_meta($term->term_id, '_my_seo_plugin_seo_title', true) ?: get_option("seo_title_taxonomy_{$term->taxonomy}", '{term_title} - {site_title}');
            $meta_description = get_term_meta($term->term_id, '_my_seo_plugin_meta_description', true) ?: get_option("meta_description_taxonomy_{$term->taxonomy}", '');
        }
    } elseif (is_post_type_archive()) {
        $post_type = get_query_var('post_type');
        $seo_title = get_option("archive_seo_title_post_type_{$post_type}", '{post_type} - {site_title}');
        $meta_description = get_option("archive_meta_description_post_type_{$post_type}", '');
    } elseif (is_404()) {
        $seo_title = get_option("seo_title_special_404", 'Страница не найдена - {site_title}');
        $meta_description = get_option("meta_description_special_404", '');
    } elseif (is_home() && !is_front_page()) { // Архив записей (не главная)
        $seo_title = get_option("archive_seo_title_post_type_post", '{post_type} - {site_title}'); 
        $meta_description = get_option("archive_meta_description_post_type_post", '');
    } elseif (is_home() || is_front_page()) { // Архив записей (главная)
        $seo_title = get_option("archive_seo_title_post_type_post", '{post_type} - {site_title}'); 
        $meta_description = get_option("archive_meta_description_post_type_post", '');
    }
    // Заменяем плейсхолдеры (если реализована соответствующая функция)
    $seo_title = apply_filters('my_seo_plugin_seo_title', replace_seo_placeholders($seo_title));
    $meta_description = apply_filters('my_seo_plugin_meta_description', replace_seo_placeholders($meta_description));

    // Выводим метатеги
    if ($seo_title) {
        echo '<title>' . esc_html($seo_title) . '</title>';
    } else {
        echo '<title>' . wp_title('|', false, 'right') . get_bloginfo('name') . '</title>';
    }

    if ($meta_description) {
        echo '<meta name="description" content="' . esc_attr($meta_description) . '">';
    }
}
add_action('wp_head', 'my_seo_plugin_output_seo_tags');



function my_seo_plugin_scripts() {
    wp_enqueue_script('my-seo-plugin-script', plugin_dir_url(__FILE__) . 'my-seo-plugin.js', array('jquery'), '1.0.0', true);
	wp_enqueue_style('my-seo-plugin-styles', plugin_dir_url(__FILE__) . 'my-seo-plugin-styles.css');
}
add_action('admin_enqueue_scripts', 'my_seo_plugin_scripts');

include plugin_dir_path(__FILE__) . 'redirects.php';
include plugin_dir_path(__FILE__) . 'sitemap.php';
include plugin_dir_path(__FILE__) . 'breadcrumbs.php';
include plugin_dir_path(__FILE__) . 'hidetaxonomyslug.php';
include plugin_dir_path(__FILE__) . '/cleanup/alpakacleanup.php';