<?php

// Добавляем дополнительные страницы только для таксономии 'softwares'
add_filter('my_custom_breadcrumbs', function($breadcrumbs) {
    // Проверяем, что это страница "Dostawcy gier" или "Metody wpłat"
    if (is_page() && (is_page('dostawcy-gier') || is_page('metody-wplat'))) {
        // Вставляем ссылку на архив 'online-casinos' после главной страницы
        array_splice($breadcrumbs, 1, 0, [
            [
                'name' => __('Online Casinos', 'my-seo-plugin'),
                'url' => get_post_type_archive_link('online-casinos')
            ]
        ]);

        // Убедимся, что последний элемент страницы отображается без ссылки
        $breadcrumbs[] = [
            'name' => get_the_title(),
            'url' => '' // Последний элемент без ссылки
        ];
    }

    return $breadcrumbs;
});



// Добавляем дополнительные страницы только для таксономии 'softwares'
add_filter('my_custom_breadcrumbs', function($breadcrumbs) {
    // Проверяем, что мы находимся на странице таксономии 'softwares'
    if (is_tax('softwares')) {
        // Удаляем предыдущую ссылку на архив, если она была добавлена
        foreach ($breadcrumbs as $key => $crumb) {
            if ($crumb['name'] === __('Gra kasynowa', 'my-seo-plugin')) {
                unset($breadcrumbs[$key]);
            }
        }

        // Перестраиваем индексы массива
        $breadcrumbs = array_values($breadcrumbs);

        // Вставляем ссылку на архив 'online-casinos' перед термином
        array_splice($breadcrumbs, -1, 0, [
            [
                'name' => __('Online Casinos', 'my-seo-plugin'),
                'url' => get_post_type_archive_link('online-casinos')
            ]
        ]);

        // Вставляем дополнительную страницу 'Dostawcy gier'
        array_splice($breadcrumbs, -1, 0, [
            ['name' => 'Dostawcy gier', 'url' => site_url('/dostawcy-gier/')]
        ]);
    }

    return $breadcrumbs;
});






add_action('alpaka_content_top', 'my_breadcrumbs', 5);

function my_breadcrumbs() {
    global $post;

    // Условия, при которых хлебные крошки не отображаются
    if (is_front_page()) {
        return;
    }

    // Начальная точка - ссылка на главную страницу
    $breadcrumbs = [
        ['name' => __('Home', 'my-seo-plugin'), 'url' => home_url()]
    ];

    // Если это одиночный пост
    if (is_singular('post')) {
        $category = get_the_category();
        if ($category) {
            $ancestors = get_ancestors($category[0]->term_id, 'category');
            foreach (array_reverse($ancestors) as $ancestor) {
                $ancestor_obj = get_category($ancestor);
                $breadcrumbs[] = ['name' => $ancestor_obj->name, 'url' => get_category_link($ancestor)];
            }
            $breadcrumbs[] = ['name' => $category[0]->name, 'url' => get_category_link($category[0]->term_id)];
        }
    } elseif (is_singular() && !is_page()) { // Кастомный тип записи
        $post_type = get_post_type_object(get_post_type());
        if ($post_type && $post_type->has_archive) {
            $breadcrumbs[] = ['name' => $post_type->labels->singular_name, 'url' => get_post_type_archive_link($post_type->name)];
        }
        $breadcrumbs[] = ['name' => get_the_title(), 'url' => ''];
    } elseif (is_category()) { // Архив категории
        $category = get_queried_object();
        $ancestors = get_ancestors($category->term_id, 'category');
        foreach (array_reverse($ancestors) as $ancestor) {
            $ancestor_obj = get_category($ancestor);
            $breadcrumbs[] = ['name' => $ancestor_obj->name, 'url' => get_category_link($ancestor)];
        }
        $breadcrumbs[] = ['name' => single_cat_title('', false), 'url' => ''];
    } elseif (is_tax()) { // Архив таксономии
        $current_term = get_queried_object();
        $taxonomy = get_taxonomy($current_term->taxonomy);

        if ($current_term->taxonomy !== 'softwares' && !empty($taxonomy->object_type)) {
            // Определяем приоритетный тип записи
            $post_type = $taxonomy->object_type[0];

            $post_type_obj = get_post_type_object($post_type);
            if ($post_type_obj && $post_type_obj->has_archive) {
                $breadcrumbs[] = [
                    'name' => $post_type_obj->labels->singular_name,
                    'url' => get_post_type_archive_link($post_type)
                ];
            }
        }

        // Добавляем родительские термины таксономии, если они есть
        $ancestors = get_ancestors($current_term->term_id, $current_term->taxonomy);
        foreach (array_reverse($ancestors) as $ancestor) {
            $ancestor_obj = get_term($ancestor, $current_term->taxonomy);
            $breadcrumbs[] = [
                'name' => $ancestor_obj->name,
                'url' => get_term_link($ancestor_obj)
            ];
        }

        // Добавляем текущий термин
        $breadcrumbs[] = [
            'name' => single_term_title('', false),
            'url' => ''
        ];
    } elseif (is_post_type_archive()) { // Архив записей
        $post_type = get_queried_object();
        if ($post_type) {
            $breadcrumbs[] = ['name' => post_type_archive_title('', false), 'url' => ''];
        }
    } elseif (is_page() && $post->post_parent) { // Страница с родителями
        $parent_id = $post->post_parent;
        $breadcrumbs_parents = [];
        while ($parent_id) {
            $parent = get_post($parent_id);
            $breadcrumbs_parents[] = ['name' => get_the_title($parent), 'url' => get_permalink($parent)];
            $parent_id = $parent->post_parent;
        }
        $breadcrumbs = array_merge($breadcrumbs, array_reverse($breadcrumbs_parents));
        $breadcrumbs[] = ['name' => get_the_title(), 'url' => ''];
    } elseif (is_tag()) { // Метка (tag)
        $breadcrumbs[] = ['name' => single_tag_title('', false), 'url' => ''];
    } elseif (is_search()) { // Поиск
        $breadcrumbs[] = ['name' => sprintf(__('Search results for "%s"', 'my-seo-plugin'), get_search_query()), 'url' => ''];
    } elseif (is_404()) { // 404
        $breadcrumbs[] = ['name' => __('404 Not Found', 'my-seo-plugin'), 'url' => ''];
    }

    // Применяем фильтр
    $breadcrumbs = apply_filters('my_custom_breadcrumbs', $breadcrumbs);

    // Вывод хлебных крошек
    echo '<nav id="breadcrumbs-container" class="is-layout-constrained pt-3 pb-3 overflow-x-auto"><ul id="breadcrumbs" class="list-reset is-layout-flex text-muted" itemscope itemtype="http://schema.org/BreadcrumbList">';
    foreach ($breadcrumbs as $index => $crumb) {
        echo '<li class="text-nowrap" itemprop="itemListElement" itemscope itemtype="http://schema.org/ListItem">';
        if (!empty($crumb['url'])) {
            echo '<a class="strong a-decoration" itemprop="item" href="' . esc_url($crumb['url']) . '"><span itemprop="name">' . esc_html($crumb['name']) . '</span></a>';
        } else {
            echo '<span itemprop="name">' . esc_html($crumb['name']) . '</span>';
        }
        echo '<meta itemprop="position" content="' . ($index + 1) . '"></li>';
        if ($index < count($breadcrumbs) - 1) {
            echo '<li class="separator"> / </li>';
        }
    }
    echo '</ul></nav>';
}












function register_breadcrumbs_block_plugin() {
    // Определяем путь к файлам плагина
    $plugin_dir = plugin_dir_url(__FILE__);
    $plugin_path = plugin_dir_path(__FILE__);

    // Регистрация скрипта для редактора блока
    wp_register_script(
        'breadcrumbs-block-editor',
        $plugin_dir . 'js/breadcrumbs-block.js', // Путь к файлу JavaScript для блока
        ['wp-blocks', 'wp-editor', 'wp-element'],
    );

    // Регистрация блока
    register_block_type('custom-plugin/breadcrumbs', [
        'editor_script' => 'breadcrumbs-block-editor',
        'render_callback' => 'render_breadcrumbs_block_plugin', // Функция рендера
    ]);
}
add_action('init', 'register_breadcrumbs_block_plugin');

// Функция рендера хлебных крошек
function render_breadcrumbs_block_plugin($attributes) {
    ob_start();
    if (function_exists('my_breadcrumbs')) {
        my_breadcrumbs(); // Вызов функции
    } else {
        echo '<!-- Function my_breadcrumbs not found -->';
    }
    return ob_get_clean();
}
