<?php
//alpaka-cleanup/admin-settings.php 
class AlpakaSeo_Admin_Settings {

    public function __construct() {
        // Добавление страницы настроек в меню WordPress
        add_action('admin_menu', array($this, 'add_settings_page'));
        // Регистрация настроек
        add_action('admin_init', array($this, 'register_settings'));
    }

	public function add_settings_page() {
		// Добавление страницы настроек как подменю
		add_submenu_page(
			'my-seo-plugin-settings',  // Родительская страница настроек
			'Сleanup Settings',     // Заголовок страницы
			'Сleanup',              // Название меню
			'manage_options',          // Требуемые права
			'alpakaсleanup-settings',      // Slug страницы
			[$this, 'settings_page_content'] // Функция для отображения контента
		);
	}

    public function register_settings() {
        // Регистрация настроек
        register_setting('alpakaseo_settings_group', 'alpakaseo_options');

        // Добавление секции настроек
        add_settings_section(
            'alpakaseo_settings_section', // ID секции
            'Настройки Alpaka SEO', // Заголовок секции
            array($this, 'settings_section_content'), // Контент секции
            'alpakaseo-settings' // Slug страницы настроек
        );

        // Добавление поля настройки "Отключение Emoji"
        add_settings_field(
            'disable_emojis', // ID поля
            'Отключить Emoji', // Заголовок поля
            array($this, 'disable_emojis_field'), // Callback для рендеринга поля
            'alpakaseo-settings', // Slug страницы настроек
            'alpakaseo_settings_section' // ID секции
        );

        // Добавление поля настройки "Отключение глобальных стилей"
        add_settings_field(
            'disable_global_styles', // ID поля
            'Отключить глобальные стили', // Заголовок поля
            array($this, 'disable_global_styles_field'), // Callback для рендеринга поля
            'alpakaseo-settings', // Slug страницы настроек
            'alpakaseo_settings_section' // ID секции
        );

        // Добавление поля настройки "Отключение стилей блоков"
        add_settings_field(
            'disable_block_library', // ID поля
            'Отключить стили блоков', // Заголовок поля
            array($this, 'disable_block_library_field'), // Callback для рендеринга поля
            'alpakaseo-settings', // Slug страницы настроек
            'alpakaseo_settings_section' // ID секции
        );

        // Добавление поля настройки "Отключение классических стилей"
        add_settings_field(
            'disable_classic_styles', // ID поля
            'Отключить классические стили', // Заголовок поля
            array($this, 'disable_classic_styles_field'), // Callback для рендеринга поля
            'alpakaseo-settings', // Slug страницы настроек
            'alpakaseo_settings_section' // ID секции
        );

        // Добавление поля настройки "Удаление ненужных ссылок и мета-тегов из хедера"
        add_settings_field(
            'remove_header_links', // ID поля
            'Удалить ненужные ссылки и мета-теги из хедера', // Заголовок поля
            array($this, 'remove_header_links_field'), // Callback для рендеринга поля
            'alpakaseo-settings', // Slug страницы настроек
            'alpakaseo_settings_section' // ID секции
        );

        // Добавление поля настройки "Оптимизация jQuery"
        add_settings_field(
            'optimize_jquery', // ID поля
            'Оптимизировать jQuery', // Заголовок поля
            array($this, 'optimize_jquery_field'), // Callback для рендеринга поля
            'alpakaseo-settings', // Slug страницы настроек
            'alpakaseo_settings_section' // ID секции
        );

        // Добавление поля настройки "Удаление стилей блоков"
        add_settings_field(
            'remove_block_styles', // ID поля
            'Удалить стили блоков', // Заголовок поля
            array($this, 'remove_block_styles_field'), // Callback для рендеринга поля
            'alpakaseo-settings', // Slug страницы настроек
            'alpakaseo_settings_section' // ID секции
        );

        // Добавление поля настройки "Удалить мета-тег генератора"
        add_settings_field(
            'add_meta_generator', // ID поля
            'Удалить мета-тег генератора', // Заголовок поля
            array($this, 'add_meta_generator_field'), // Callback для рендеринга поля
            'alpakaseo-settings', // Slug страницы настроек
            'alpakaseo_settings_section' // ID секции
        );
    }

    public function settings_section_content() {
        echo '<p>Настройки для оптимизации вашего WordPress сайта.</p>';
    }

    public function disable_emojis_field() {
        $options = get_option('alpakaseo_options');
        $checked = isset($options['disable_emojis']) ? 'checked' : '';
        echo '<input type="checkbox" name="alpakaseo_options[disable_emojis]" ' . $checked . '>';
    }

    public function disable_global_styles_field() {
        $options = get_option('alpakaseo_options');
        $checked = isset($options['disable_global_styles']) ? 'checked' : '';
        echo '<input type="checkbox" name="alpakaseo_options[disable_global_styles]" ' . $checked . '>';
    }

    public function disable_block_library_field() {
        $options = get_option('alpakaseo_options');
        $checked = isset($options['disable_block_library']) ? 'checked' : '';
        echo '<input type="checkbox" name="alpakaseo_options[disable_block_library]" ' . $checked . '>';
    }

    public function disable_classic_styles_field() {
        $options = get_option('alpakaseo_options');
        $checked = isset($options['disable_classic_styles']) ? 'checked' : '';
        echo '<input type="checkbox" name="alpakaseo_options[disable_classic_styles]" ' . $checked . '>';
    }

    public function remove_header_links_field() {
        $options = get_option('alpakaseo_options');
        $checked = isset($options['remove_header_links']) ? 'checked' : '';
        echo '<input type="checkbox" name="alpakaseo_options[remove_header_links]" ' . $checked . '>';
    }

    public function optimize_jquery_field() {
        $options = get_option('alpakaseo_options');
        $checked = isset($options['optimize_jquery']) ? 'checked' : '';
        echo '<input type="checkbox" name="alpakaseo_options[optimize_jquery]" ' . $checked . '>';
    }

    public function remove_block_styles_field() {
        $options = get_option('alpakaseo_options');
        $checked = isset($options['remove_block_styles']) ? 'checked' : '';
        echo '<input type="checkbox" name="alpakaseo_options[remove_block_styles]" ' . $checked . '>';
    }

    public function add_meta_generator_field() {
        $options = get_option('alpakaseo_options');
        $checked = isset($options['add_meta_generator']) ? 'checked' : '';
        echo '<input type="checkbox" name="alpakaseo_options[add_meta_generator]" ' . $checked . '>';
    }

    public function settings_page_content() {
        ?>
        <div class="wrap">
            <h1>Alpaka SEO Settings</h1>
            <form method="post" action="options.php">
                <?php
                settings_fields('alpakaseo_settings_group');
                do_settings_sections('alpakaseo-settings');
                submit_button();
                ?>
            </form>
        </div>
        <?php
    }
}

new AlpakaSeo_Admin_Settings();