<?php
// Если файл вызывается напрямую, завершаем выполнение.
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}
function remove_auto_sizes_css_fix($add_auto_sizes) {return false;}
add_filter('wp_img_tag_add_auto_sizes', 'remove_auto_sizes_css_fix');
// Подключаем файл с классом настроек, если он существует.
if ( file_exists( plugin_dir_path( __FILE__ ) . 'admin-settings.php' ) ) {
    require_once plugin_dir_path( __FILE__ ) . 'admin-settings.php';
}
	

class My_WordPress_Cleanup {

	/**
	 * Инициализация плагина.
	 */
	public function __construct() {

        // Получаем настройки плагина
        $options = get_option('alpakaseo_options');

        // Проверяем условия и добавляем соответствующие действия
        if (isset($options['disable_emojis']) && $options['disable_emojis'] === 'on') {
            add_action('init', array($this, 'disable_emojis'));
        }

        if (isset($options['disable_global_styles']) && $options['disable_global_styles'] === 'on') {
       		remove_action( 'wp_enqueue_scripts', 'wp_enqueue_global_styles' );
		}

        if (isset($options['disable_block_library']) && $options['disable_block_library'] === 'on') {
            add_action('wp_enqueue_scripts', array($this, 'disable_block_library_styles'), 100);
        }

        if (isset($options['disable_classic_styles']) && $options['disable_classic_styles'] === 'on') {
            add_action('wp_enqueue_scripts', array($this, 'disable_classic_theme_styles'), 100);
        }

        if (isset($options['remove_header_links']) && $options['remove_header_links'] === 'on') {
            add_action('init', array($this, 'remove_unnecessary_header_info'));
        }

        if (isset($options['optimize_jquery']) && $options['optimize_jquery'] === 'on') {
            add_action('wp_enqueue_scripts', array($this, 'optimize_jquery'), 11);
        }
        
        // Добавляем проверку на удаление стилей блоков, если эта опция включена в настройках
        if (isset($options['remove_block_styles']) && $options['remove_block_styles'] === 'on') {
            add_action('wp_footer', array($this, 'remove_block_styles'));
        }

        // Удаляем мета-тег генератора, если эта опция включена в настройках
        if (isset($options['add_meta_generator']) && $options['add_meta_generator'] === 'on') {
            add_action('init', array($this, 'remove_meta_generator'));
        }
    }

    // Метод для удаления мета-тега генератора
    public function remove_meta_generator() {
        remove_action('wp_head', 'wp_generator'); // Удаляет информацию о версии WordPress
    }

    /**
	 * Удаление ненужных ссылок и мета-тегов из хедера.
	 */
	public function remove_unnecessary_header_info() {
	    remove_action('wp_head', 'rsd_link'); // Удаляет RSD link	    
		remove_action('wp_head', 'feed_links', 2); // Удаляет ссылки RSS feed
	    remove_action('wp_head', 'index_rel_link'); // Удаляет index link
	    remove_action('wp_head', 'wlwmanifest_link'); // Удаляет wlwmanifest
	    remove_action('wp_head', 'feed_links_extra', 3); // Удаляет ссылки дополнительных RSS feed
	    remove_action('wp_head', 'start_post_rel_link', 10, 0); // Удаляет случайные ссылки на предыдущие статьи
	    remove_action('wp_head', 'parent_post_rel_link', 10, 0); // Удаляет ссылки на родительские статьи
	    remove_action('wp_head', 'adjacent_posts_rel_link', 10, 0); // Удаляет соседние ссылки на статьи
	    remove_action('wp_head', 'wp_shortlink_wp_head', 10, 0); // Удаляет короткие ссылки
	    remove_action('wp_head', 'rest_output_link_wp_head', 10); // Удаляет ссылки REST API
	}

	/**
	 * Отключение emoji скриптов и стилей.
	 */
	public function disable_emojis() {
		remove_action( 'wp_head', 'print_emoji_detection_script', 7 );
		remove_action( 'admin_print_scripts', 'print_emoji_detection_script' );
		remove_action( 'wp_print_styles', 'print_emoji_styles' );
		remove_action( 'admin_print_styles', 'print_emoji_styles' );	
		remove_filter( 'the_content_feed', 'wp_staticize_emoji' );
		remove_filter( 'comment_text_rss', 'wp_staticize_emoji' );	
		remove_filter( 'wp_mail', 'wp_staticize_emoji_for_email' );
		add_filter( 'tiny_mce_plugins', array( $this, 'disable_emojis_tinymce' ) );
		add_filter( 'wp_resource_hints', array( $this, 'disable_emojis_remove_dns_prefetch' ), 10, 2 );
	}

	/**
	 * Фильтр плагинов TinyMCE для удаления emoji плагина.
	 */
	public function disable_emojis_tinymce( $plugins ) {
		if ( is_array( $plugins ) ) {
			return array_diff( $plugins, array( 'wpemoji' ) );
		} else {
			return array();
		}
	}

	/**
	 * Удаление emoji DNS prefetching.
	 */
	public function disable_emojis_remove_dns_prefetch( $urls, $relation_type ) {
		if ( 'dns-prefetch' == $relation_type ) {
			// Strip out any URLs referencing the WordPress emoji location
			$emoji_svg_url = 'https://s.w.org/images/core/emoji/';
			foreach ( $urls as $key => $url ) {
				if ( strpos( $url, $emoji_svg_url ) !== false ) {
					unset( $urls[$key] );
				}
			}
		}

		return $urls;
	}

    // Метод для удаления стилей блоков
    public function remove_block_styles() {
        wp_dequeue_style('core-block-supports');
        wp_dequeue_style('core-block-supports-inline-css'); // Идентификатор вашего стиля
    }

	/**
	 * Отключение стилей блоков WordPress.
	 */
	public function disable_block_library_styles() {
		wp_dequeue_style('wp-block-library');
	}

	/**
	 * Отключение классических тематических стилей.
	 */
	public function disable_classic_theme_styles() {
		wp_deregister_style('classic-theme-styles');
		wp_dequeue_style('classic-theme-styles');
	}

    /**
     * Оптимизация jQuery.
     */
    public function optimize_jquery() {
        // Deregister WordPress jQuery and register optimized version
        wp_deregister_script('jquery-core');
        wp_deregister_script('jquery');

        // Register the Google CDN version of jQuery
        wp_register_script('jquery-core', 'https://ajax.googleapis.com/ajax/libs/jquery/3.7.1/jquery.min.js', [], null, true);
        
        // Register a dummy 'jquery' script to maintain compatibility with plugins that enqueue 'jquery' rather than 'jquery-core'.
        wp_register_script('jquery', false, ['jquery-core'], null, true);

        // Enqueue the registered script
        wp_enqueue_script('jquery');
    }

}

// Инициализация нашего класса плагина.
new My_WordPress_Cleanup();