<?php

//------------------------------------------------------------------------------
// ADD SETTING PAGE
//------------------------------------------------------------------------------


// 1. 1
add_action('admin_menu', 'alpaka_add_settings_page');
function alpaka_add_settings_page() {
    add_submenu_page(
        'my-seo-plugin-settings',
        __('Скрыть слаг таксономии', 'alpaka-hide-taxonomy-slug'),
        __('Скрыть слаг', 'alpaka-hide-taxonomy-slug'),
        'manage_options',
        'hide-slug-settings',
        'alpaka_render_settings_page'
    );
}

// 1. 2
function alpaka_render_settings_page() {
    $all_taxonomies = get_taxonomies(['public' => true], 'objects');
    $excluded_taxonomies = ['post_format', 'wp_pattern_category'];
    $custom_taxonomies = array_diff_key($all_taxonomies, array_flip($excluded_taxonomies));

    if ($_SERVER['REQUEST_METHOD'] == 'POST') {
        check_admin_referer('update-hide_slug_settings');

        if (current_user_can('manage_options')) {
            update_option('hide_slug_taxonomies', $_POST['taxonomies'] ?? []);
            echo '<div id="message" class="updated notice is-dismissible"><p>' . __('Настройки сохранены.', 'alpaka-hide-taxonomy-slug') . '</p></div>';
        } else {
            echo '<div id="message" class="error"><p>' . __('У вас нет прав для выполнения этой операции.', 'alpaka-hide-taxonomy-slug') . '</p></div>';
        }
    }

    $selected_taxonomies = get_option('hide_slug_taxonomies', []);

    echo '<div class="wrap">';
    echo '<h2>' . __('Настройки скрытия слагов таксономий', 'alpaka-hide-taxonomy-slug') . '</h2>';
    echo '<p>' . __('Выберите таксономии, для которых вы хотите скрыть слаги:', 'alpaka-hide-taxonomy-slug') . '</p>';
    echo '<form method="post" style="padding:20px; border:1px solid #eee; background-color:#fafafa;">';
    wp_nonce_field('update-hide_slug_settings');
    foreach ($custom_taxonomies as $tax) {
        echo '<label style="display: block; margin-bottom: 10px;">';
        echo '<input type="checkbox" name="taxonomies[]" value="' . esc_attr($tax->name) . '" ' . (in_array($tax->name, $selected_taxonomies) ? 'checked' : '') . '>';
        echo esc_html($tax->labels->name);
        echo '</label>';
    }
    echo '<input type="submit" class="button-primary" value="' . __('Сохранить', 'alpaka-hide-taxonomy-slug') . '">';
    echo '</form>';
    echo '</div>';
}



//------------------------------------------------------------------------------
//  Remove taxonomy slugs (categories, post tags and custom taxonomies) from URL
//  Resource Link: https://rudrastyh.com/wordpress/remove-taxonomy-slug-from-urls.html
//  https://gist.github.com/raazon/f482432e1e8290ef4b0afa8ad65155ad
//------------------------------------------------------------------------------


// 2. 1
// Эта функция делает доступным URL уже без слага (не выдает 404 ошибку)

add_filter( 'request', 'rudr_change_term_request', 1, 1 );
add_filter( 'rewrite_rules_array', 'rudr_modify_rewrite_rules' );
add_action( 'init', 'rudr_flush_rewrite_rules' );

function rudr_change_term_request( $query ) {

    $taxonomies = get_option('hide_slug_taxonomies', []); // Получаем список таксономий

    if ( empty($taxonomies) || ! is_array($taxonomies) ) {
        return $query;
    }

    foreach ($taxonomies as $tax_name) {
        $include_children = false;
        $name = '';

        if ( isset($query['attachment']) ) {
            $include_children = true;
            $name = $query['attachment'];
        } elseif ( isset($query['name']) ) {
            $name = $query['name'];
        }

        if ( empty($name) ) {
            continue;
        }

        $term = get_term_by( 'slug', $name, $tax_name );

        if ( ! is_wp_error($term) && $term ) {
            if ( $include_children ) {
                unset( $query['attachment'] );
                $parent = $term->parent;
                while ( $parent ) {
                    $parent_term = get_term( $parent, $tax_name );
                    if ( ! $parent_term ) {
                        break;
                    }
                    $name = "{$parent_term->slug}/{$name}";
                    $parent = $parent_term->parent;
                }
            } else {
                unset( $query['name'] );
            }

            switch( $tax_name ) {
                case 'category':
                    $query['category_name'] = $name;
                    break;
                case 'post_tag':
                    $query['tag'] = $name;
                    break;
                default:
                    $query[$tax_name] = $name;
                    break;
            }
        }
    }

    return $query;
}
// Функция для добавления новых правил перезаписи
function rudr_modify_rewrite_rules( $rules ) {
    $taxonomies = get_option('hide_slug_taxonomies', []); 

    if ( empty($taxonomies) || ! is_array($taxonomies) ) {
        return $rules;
    }

    $new_rules = [];

    foreach ( $taxonomies as $taxonomy ) {
        // Пропускаем категории (category)
        if ( $taxonomy === 'category' ) {
            continue;
        }

        $terms = get_terms( $taxonomy, array( 'hide_empty' => false ) );

        if ( empty($terms) || is_wp_error($terms) ) {
            continue;
        }

        foreach ( $terms as $term ) {
            $term_slug = $term->slug;

            // Добавляем кастомные правила только для таксономий, кроме category
            $new_rules["({$term_slug})/(?:feed/)?(feed|rdf|rss|rss2|atom)/?$"] = 'index.php?' . $taxonomy . '=$matches[1]&feed=$matches[2]';
            $new_rules["({$term_slug})/page/?([0-9]{1,})/?$"] = 'index.php?' . $taxonomy . '=$matches[1]&paged=$matches[2]';
            $new_rules["({$term_slug})/?$"] = 'index.php?' . $taxonomy . '=$matches[1]';
        }
    }

    return $new_rules + $rules; // Добавляем новые правила к существующим
}


// Очистка rewrite-правил при изменении настроек
function rudr_flush_rewrite_rules() {
    flush_rewrite_rules();
}
add_action( 'update_option_hide_slug_taxonomies', 'rudr_flush_rewrite_rules' );


// 2. 2
// Меняем постоянную ссылку со старой на новую
// Сейчас так же страница доступна по двум URL (если стоит rewrite, то по трём URL), но теперь в админке и меню уже новый URL 

add_filter( 'term_link', 'ic_term_permalink', 10, 3 );
function ic_term_permalink( $url, $term, $taxonomy ){
    // Получаем массив допустимых таксономий из настроек
    $taxonomy_names = get_option('hide_slug_taxonomies', []);

    // Получаем слаги для каждой таксономии
    $taxonomy_slugs = array_map(function($name) {
        $tax_obj = get_taxonomy($name);
        return $tax_obj ? $tax_obj->rewrite['slug'] : null;
    }, $taxonomy_names);

    // Создаём ассоциативный массив, связывающий названия таксономий со слагами
    $taxonomy_map = array_combine($taxonomy_names, $taxonomy_slugs);

    // Проверяем, есть ли слаг таксономии в URL и соответствует ли таксономия одной из допустимых
    if (array_key_exists($taxonomy, $taxonomy_map) && strpos($url, $taxonomy_map[$taxonomy]) !== false) {
		$url = preg_replace('#/' . preg_quote($taxonomy_map[$taxonomy], '/') . '/#', '/', $url, 1);
        return $url; // Возвращаем изменённый URL
    }
    
    return $url; // Возвращаем оригинальный URL, если таксономия не соответствует ни одной из допустимых
}


// 2. 3
// Редирект со сторого на новый юрл
add_action('template_redirect', 'ic_old_term_redirect');
function ic_old_term_redirect() {
    // Получаем массив допустимых таксономий из настроек
    $taxonomy_names = get_option('hide_slug_taxonomies', []);

    // Проверяем каждую таксономию
    foreach ($taxonomy_names as $taxonomy_name) {
        // Получаем объект таксономии
        $taxonomy_object = get_taxonomy($taxonomy_name);
        if (!$taxonomy_object) {
            continue;
        }

        // Получаем слаг для текущей таксономии
        $taxonomy_slug = $taxonomy_object->rewrite['slug'];

        // Проверяем, присутствует ли слаг в URL
        if (strpos($_SERVER['REQUEST_URI'], '/' . $taxonomy_slug . '/') === false) {
            continue;
        }

        // Проверяем, соответствует ли текущая страница данной таксономии
        if ((is_category() && $taxonomy_name == 'category') || (is_tag() && $taxonomy_name == 'post_tag') || is_tax($taxonomy_name)) {
            // Строим новый URL, убирая слаг из текущего URI
            $new_url = site_url(str_replace('/' . $taxonomy_slug . '/', '/', $_SERVER['REQUEST_URI']));
            
            // Выполняем перенаправление
            wp_redirect($new_url, 301);
            exit;
        }
    }
}
