<?php
// Добавляем страницу настроек для редиректов в меню плагина
add_action('admin_menu', 'my_seo_plugin_add_redirect_settings_page');
function my_seo_plugin_add_redirect_settings_page() {
    add_submenu_page(
        'my-seo-plugin-settings',  // Родительская страница настроек плагина
        'Управление редиректами',  // Заголовок страницы
        'Редиректы',               // Название меню
        'manage_options',          // Права доступа (только администраторы)
        'my-seo-plugin-redirect-settings',  // Уникальный slug страницы
        'my_seo_plugin_redirect_settings_page'  // Функция для рендеринга страницы
    );
}

// Функция для рендеринга страницы настроек редиректов
function my_seo_plugin_redirect_settings_page() {
    ?>
    <div class="wrap">
        <h1>Управление редиректами</h1>
        <form method="post" action="options.php">
            <?php
            // Вывод формы для сохранения настроек
            settings_fields('my_seo_plugin_redirects_group');
            do_settings_sections('my-seo-plugin-redirect-settings');
            submit_button();
            ?>
        </form>

        <script type="text/javascript">
            // Функция для удаления строки при нажатии кнопки "Удалить"
            function removeRow(button) {
                // Находим родительскую строку (tr) и удаляем её
                var row = button.parentElement.parentElement;
                row.parentElement.removeChild(row);
            }
        </script>
    </div>
    <?php
}

// Регистрация настроек для редиректов
add_action('admin_init', 'my_seo_plugin_register_redirect_settings');
function my_seo_plugin_register_redirect_settings() {
    // Регистрируем массив редиректов как опцию
    register_setting('my_seo_plugin_redirects_group', 'my_seo_plugin_redirects', 'my_seo_plugin_validate_redirects');

    // Добавляем секцию для редиректов на странице настроек
    add_settings_section(
        'my_seo_plugin_redirects_section',
        'Редиректы',
        'my_seo_plugin_redirects_section_callback',
        'my-seo-plugin-redirect-settings'
    );

    // Добавляем поле для управления редиректами
    add_settings_field(
        'my_seo_plugin_redirects',
        'Редиректы',
        'my_seo_plugin_redirects_callback',
        'my-seo-plugin-redirect-settings',
        'my_seo_plugin_redirects_section'
    );
}

// Функция обратного вызова для секции настроек редиректов
function my_seo_plugin_redirects_section_callback() {
    echo '<p>Добавьте ваши редиректы. Укажите старый URL (без домена), новый URL и тип редиректа (301 или 302). Также можно удалить ненужные строки.</p>';
}

// Функция обратного вызова для вывода полей редиректов
function my_seo_plugin_redirects_callback() {
    // Получаем существующие редиректы из базы данных (опции)
    $redirects = get_option('my_seo_plugin_redirects', []);

    // Выводим таблицу с полями для редиректов
    echo '<table>';
    echo '<tr><th>Старый URL</th><th>Новый URL</th><th>Тип редиректа</th><th>Действие</th></tr>';
    
    // Если уже есть сохранённые редиректы, отображаем их
    if (!empty($redirects)) {
        foreach ($redirects as $redirect) {
            echo '<tr>';
            echo '<td><input type="text" name="my_seo_plugin_redirects[old_url][]" value="' . esc_attr($redirect['old_url']) . '" /></td>';
            echo '<td><input type="text" name="my_seo_plugin_redirects[new_url][]" value="' . esc_attr($redirect['new_url']) . '" /></td>';
            echo '<td>
                    <select name="my_seo_plugin_redirects[type][]">
                        <option value="301"' . selected($redirect['type'], '301', false) . '>301</option>
                        <option value="302"' . selected($redirect['type'], '302', false) . '>302</option>
                    </select>
                  </td>';
            echo '<td><button type="button" onclick="removeRow(this)">Удалить</button></td>';
            echo '</tr>';
        }
    }

    // Пустые поля для добавления новых редиректов (без кнопки удаления)
    echo '<tr>';
    echo '<td><input type="text" name="my_seo_plugin_redirects[old_url][]" value="" placeholder="/old-url" /></td>';
    echo '<td><input type="text" name="my_seo_plugin_redirects[new_url][]" value="" placeholder="/new-url" /></td>';
    echo '<td>
            <select name="my_seo_plugin_redirects[type][]">
                <option value="301">301</option>
                <option value="302">302</option>
            </select>
          </td>';
    echo '<td></td>';  // Оставляем пустым, чтобы не отображать кнопку "Удалить" для этой строки
    echo '</tr>';

    echo '</table>';
}

// Валидация данных редиректов перед сохранением
function my_seo_plugin_validate_redirects($input) {
    $valid = [];

    // Проверяем, что старый и новый URL заданы, чтобы сохранить только заполненные поля
    if (!empty($input['old_url']) && !empty($input['new_url'])) {
        foreach ($input['old_url'] as $index => $old_url) {
            $new_url = sanitize_text_field($input['new_url'][$index]);
            $type = sanitize_text_field($input['type'][$index]);

            // Если оба URL заполнены, добавляем их в массив для сохранения
            if (!empty($old_url) && !empty($new_url)) {
                $valid[] = [
                    'old_url' => untrailingslashit(sanitize_text_field($old_url)),  // Убираем завершающий слэш
                    'new_url' => untrailingslashit($new_url),
                    'type'    => in_array($type, ['301', '302']) ? $type : '301',  // По умолчанию 301
                ];
            }
        }
    }

    return $valid;
}

// Функция для выполнения редиректов на основе полного URL (без домена)
add_action('template_redirect', 'my_seo_plugin_handle_redirects', 1);  // Приоритет 1 для раннего выполнения
function my_seo_plugin_handle_redirects() {
    // Получаем массив редиректов, сохранённых в настройках
    $redirects = get_option('my_seo_plugin_redirects', []);

    // Проверяем, есть ли редиректы
    if (!empty($redirects)) {
        // Получаем текущий URL без домена и без завершающего слэша
        $current_url = untrailingslashit($_SERVER['REQUEST_URI']);  // Полный URL без домена

        foreach ($redirects as $redirect) {
            // Убираем завершающий слэш у старого URL и проверяем соответствие полного URL
            $old_url = untrailingslashit($redirect['old_url']);

            // Если текущий URL совпадает со старым URL, выполняем редирект
            if ($current_url === $old_url) {
                wp_redirect(home_url($redirect['new_url']), $redirect['type']);
                exit();
            }
        }
    }
}